/* ------------------------------------------------------------------
                              i2c_scan.c

     Software I2C Bitbanging mit ATtiny44

     Scant den I2C Bus nach angeschlossenen Teilnehmern und gibt
     die Hexadresse des I2C-Device auf dem UART aus.


     MCU   : ATtiny44
     F_CPU : 8 MHz intern

     Fuses : fuer 8 MHz intern
             lo 0xe2
             hi 0xdf

     Fuses : fuer ext. Quarz >= 8 MHz
             lo 0xde
             hi 0xdf


     Pinbelegung I2C
     ---------------
     PB0 = SDA
     PB1 = SCL


     Pinbelegung UART
     ----------------
     PA5 = D0 = TxD


     12.09.2018 R. Seelig
   ------------------------------------------------------------------ */

/*
                                                 ATtiny44
                                        4 kByte Flash / 256 Byte SRAM

                                             Anschlusspins IC

                                              +-----------+
                                         Vcc  | 1      14 |  GND
                   PCINT8 - XTAL1 - CLKI PB0  | 2   A  13 |  PA0 - ADC0 - AREF - PCINT0
                        PCINT9 - XTAL2 - PB1  | 3   T  12 |  PA1 - ADC1 - AIN0 - PCINT1
                 PCINT11 - /reset - dW - PB3  | 4   t  11 |  PA2 - ADC2 - AIN1 - PCINT2
         PCINT10 - INT0 - OC0A - CKOUT - PB2  | 5   i  10 |  PA3 - ADC3 - T0 - PCINT3
            PCINT7 - ICP - OC0B - ADC7 - PA7  | 6   n   9 |  PA4 - ADC4 - USCK - SCL - T1 - PCINT4
PCINT6 - OC1A - SDA - MOSI - DI - ADC6 - PA6  | 7   y   8 |  PA5 - ADC5 - DO - MISO - OC1B PCINT5
                                              +-----------+

*/

#include <util/delay.h>
#include <avr/io.h>

#include "avr_gpio.h"
#include "i2c_sw.h"
#include "usiuart.h"
#include "my_printf.h"

#define  delay                _delay_ms
#define  printf               my_printf

#define cnt_speed    500

#define led_init()     PA1_output_init()
#define led_clr()      PA1_set()
#define led_set()      PA1_clr()



/* --------------------------------------------------------
   my_putchar

   wird von my-printf / printf aufgerufen und hier muss
   eine Zeichenausgabefunktion angegeben sein, auf das
   printf dann schreibt !
   -------------------------------------------------------- */
void my_putchar(char ch)
{
  uart_putchar(ch);
}


int main(void)
{
  uint8_t ch;
  uint8_t cx,anz;
  uint8_t ack;


  printfkomma= 3;

  uart_init();
  i2c_master_init();

  printf("\n\rI2C Bus scanning\n\r--------------------------\n\n\r" \
         "Devices found at address:\n\n\r");

  anz= 0;

  for (cx= 1; cx< 127; cx++)
  {
    ack= i2c_start(cx << 1);
    delay(1);
    i2c_stop();
    if (ack)
    {
      printf("%xh  ",(cx << 1));
      anz++;
      anz= anz % 5;
      if (!anz) printf("\n\r");
    }
    delay(1);
  }
  printf("\n\n\rEnd of I2C-bus scanning... \n\n\r");
  i2c_stop();

  while(1)
  {
  }
}
